==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicPopupMenuUI__24PopupMenuHandler.h <==
// class javax.swing.plaf.basic.BasicPopupMenuUI$PopupMenuHandler

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a51d95d0fb1d0fc9 javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler_H_
#define _JC_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_event_PopupMenuEvent$object;
struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI$object;
struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__241$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$sub_refs	_jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$refs	_jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$nonrefs	_jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$object	_jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$vmethods	_jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$vtable	_jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$vtype	_jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$method$_init$84d44dbc97f08e44(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$object *, struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI$object *);
extern void _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$method$_init$946abcd8bf8c5c85(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$object *, struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI$object *, struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__241$object *);

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$method$popupMenuCanceled$35dba724ed0eeabc(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$object *, struct _jc_javax_swing_event_PopupMenuEvent$object *);
extern void _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$method$popupMenuWillBecomeInvisible$72cb3d28284d8e97(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$object *, struct _jc_javax_swing_event_PopupMenuEvent$object *);
extern void _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$method$popupMenuWillBecomeVisible$0b181f87360f700a(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$object *, struct _jc_javax_swing_event_PopupMenuEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$method_info$popupMenuCanceled$35dba724ed0eeabc;
extern _jc_method _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$method_info$popupMenuWillBecomeInvisible$72cb3d28284d8e97;
extern _jc_method _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$method_info$popupMenuWillBecomeVisible$0b181f87360f700a;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$vmethods {
	void	(*popupMenuCanceled$35dba724ed0eeabc)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$object *, struct _jc_javax_swing_event_PopupMenuEvent$object *);
	void	(*popupMenuWillBecomeInvisible$72cb3d28284d8e97)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$object *, struct _jc_javax_swing_event_PopupMenuEvent$object *);
	void	(*popupMenuWillBecomeVisible$0b181f87360f700a)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$object *, struct _jc_javax_swing_event_PopupMenuEvent$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$vmethods	javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$refs {
    _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$sub_refs	javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$sub_nonrefs	javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$object {
	_jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$vtype _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicPopupMenuUI__24PopupMenuHandler.h <==
// class javax.swing.plaf.basic.BasicPopupMenuUI$PopupMenuHandler

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 42c705a6dfa84c40 javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler_H_
#define _JC_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_event_PopupMenuEvent$object;
struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI$object;
struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__241$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$sub_refs	_jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$refs	_jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$nonrefs	_jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$object	_jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$vmethods	_jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$vtable	_jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$vtype	_jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$method$_init$84d44dbc97f08e44(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$object *, struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$method$_init$946abcd8bf8c5c85(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$object *, struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI$object *, struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__241$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$method$popupMenuCanceled$35dba724ed0eeabc(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$object *, struct _jc_javax_swing_event_PopupMenuEvent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$method$popupMenuWillBecomeInvisible$72cb3d28284d8e97(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$object *, struct _jc_javax_swing_event_PopupMenuEvent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$method$popupMenuWillBecomeVisible$0b181f87360f700a(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$object *, struct _jc_javax_swing_event_PopupMenuEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$method_info$popupMenuCanceled$35dba724ed0eeabc;
extern _jc_method _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$method_info$popupMenuWillBecomeInvisible$72cb3d28284d8e97;
extern _jc_method _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$method_info$popupMenuWillBecomeVisible$0b181f87360f700a;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$vmethods {
	void	(*popupMenuCanceled$35dba724ed0eeabc)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$object *, struct _jc_javax_swing_event_PopupMenuEvent$object *) _JC_JCNI_ATTR;
	void	(*popupMenuWillBecomeInvisible$72cb3d28284d8e97)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$object *, struct _jc_javax_swing_event_PopupMenuEvent$object *) _JC_JCNI_ATTR;
	void	(*popupMenuWillBecomeVisible$0b181f87360f700a)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$object *, struct _jc_javax_swing_event_PopupMenuEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$vmethods	javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$refs {
    _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$sub_refs	javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$sub_nonrefs	javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$object {
	_jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$vtype _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicPopupMenuUI__24PopupMenuHandler_H_ */
